PtrByteSlice

Struct PtrByteSlice 

pub struct PtrByteSlice<'a> { /* private fields */ }
A read-only view of a raw pointer byte slice, providing a safe API.

Implementations

Source

impl<'a> PtrByteSlice<'a>

pub unsafe fn new(slice: *const [u8]) -> Self

Creates a new PtrByteSlice from a raw pointer to a byte slice.

Safety

The caller must ensure that slice is valid for reads for the lifetime 'a.

pub fn len(&self) -> usize

Returns the length of the slice in bytes.

pub fn is_empty(&self) -> bool

Returns true if the slice has a length of 0.

pub fn read<T: Copy + FromBytes>(&self) -> Option<T>

Reads a copy of a value of type T from the start of the slice.

The read is performed unaligned, so the slice does not need to be aligned to T.

pub fn copy_to_slice(&self, dest: &mut [u8])

Copies the contents of this slice into a safe Rust mutable slice.

Panics

Panics if dest is smaller than self.len().

pub fn subslice(&self, range: Range<usize>) -> Self

Returns a subslice of this pointer slice.

Panics

Panics if the range is out of bounds.

pub fn split_at(self, mid: usize) -> (Self, Self)

Splits the slice into two at the given index.

Panics

Panics if mid is out of bounds.

pub fn as_raw_slice_ptr(&self) -> *const [u8]

Returns the raw pointer to the slice.

pub fn as_ptr(&self) -> *const u8

Returns a raw pointer to the start of the slice.

pub fn to_vec(&self) -> Vec<u8>

Allocates a new heap Vector and copies the contents into it. Bypasses zero-initialization using raw pointer copies.

pub fn append_to(&self, vec: &mut Vec<u8>)

Appends the contents of this slice to the given vector, expanding its capacity if needed. Bypasses zero-initialization using raw pointer copies.

pub fn chunks<T: Copy + FromBytes>(&self) -> Chunks<'_, T>

Returns an iterator over read-only chunks of type T.

Panics

Panics if the slice is not aligned to T or if its length in bytes is not a multiple of size_of::<T>().