pub struct Writer<'a> { /* private fields */ }Expand description
An io::Write adapter for MutPtrByteSlice.
Implementations
Sourceimpl<'a> Writer<'a>
impl<'a> Writer<'a>
Sourcepub fn new(slice: MutPtrByteSlice<'a>) -> Self
pub fn new(slice: MutPtrByteSlice<'a>) -> Self
Creates a new writer from a MutPtrByteSlice.
Sourcepub fn position(&self) -> usize
pub fn position(&self) -> usize
Returns the number of bytes written so far (the current position of the writer).
Sourcepub fn remaining(&mut self) -> MutPtrByteSlice<'_>
pub fn remaining(&mut self) -> MutPtrByteSlice<'_>
Returns the remaining unwritten subslice of the buffer.
Sourcepub fn into_written(self) -> MutPtrByteSlice<'a>
pub fn into_written(self) -> MutPtrByteSlice<'a>
Consumes the writer and returns the subslice containing the data written so far.