pub struct PtrByteSlice<'a> { /* private fields */ }Expand description
A read-only view of a raw pointer byte slice, providing a safe API.
Implementations
Sourceimpl<'a> PtrByteSlice<'a>
impl<'a> PtrByteSlice<'a>
Sourcepub unsafe fn new(slice: *const [u8]) -> Self
pub unsafe fn new(slice: *const [u8]) -> Self
Creates a new PtrByteSlice from a raw pointer to a byte slice.
Safety
The caller must ensure that slice is valid for reads for the lifetime 'a.
Sourcepub fn read<T: Copy + FromBytes>(&self) -> Option<T>
pub fn read<T: Copy + FromBytes>(&self) -> Option<T>
Reads a copy of a value of type T from the start of the slice.
The read is performed unaligned, so the slice does not need to be aligned to T.
Sourcepub fn copy_to_slice(&self, dest: &mut [u8])
pub fn copy_to_slice(&self, dest: &mut [u8])
Copies the contents of this slice into a safe Rust mutable slice.
Panics
Panics if dest is smaller than self.len().
Sourcepub fn as_raw_slice_ptr(&self) -> *const [u8]
pub fn as_raw_slice_ptr(&self) -> *const [u8]
Returns the raw pointer to the slice.
Sourcepub fn to_vec(&self) -> Vec<u8> ⓘ
pub fn to_vec(&self) -> Vec<u8> ⓘ
Allocates a new heap Vector and copies the contents into it. Bypasses zero-initialization using raw pointer copies.